@@ -20,7 +20,7 @@ def get_vol6_64(nums: int):
     # dir_path = abspath('tool.py')
     # print(sys.path[0])
     # chdir(dir_path[0])
-    real_path = join(sys.path[0],'./vol6_64.npy')
+    real_path = join(sys.path[0],'./vol6_64.py')
     # abs_path = abspath('tool.py')
     # print(abs_path)
     data = load(real_path)
